@@ -3,21 +3,27 @@ from ftw.solr.connection import SolrConnection
 from ftw.solr.connection import SolrConnectionConfig
 from ftw.solr.connection import SolrConnectionManager
 from ftw.solr.connection import SolrResponse
-from ftw.solr.tests.utils import get_data
-from ftw.solr.tests.utils import MockHTTPResponse
-from ftw.solr.tests.utils import MockBlob
 from ftw.solr.interfaces import ISolrConnectionConfig
-from mock import patch
+from ftw.solr.interfaces import ISolrSettings
+from ftw.solr.testing import FTW_SOLR_INTEGRATION_TESTING
+from ftw.solr.tests.utils import get_data
+from ftw.solr.tests.utils import MockBlob
+from ftw.solr.tests.utils import MockHTTPResponse
 from mock import MagicMock
-from zope.component import provideUtility
+from mock import patch
+from plone.registry.interfaces import IRegistry
 from plone.testing import zca
-import unittest
-import transaction
+from zope.component import provideUtility
+from zope.component import queryUtility
 import socket
+import transaction
+import unittest
 
 
 class TestConnection(unittest.TestCase):
 
+    layer = FTW_SOLR_INTEGRATION_TESTING
+
     def test_connection_initialization(self):
         conn = SolrConnection(host='mysolrserver', base='/solr/mycore')
         self.assertEqual(conn.conn.host, 'mysolrserver')
@@ -80,7 +86,7 @@ class TestConnection(unittest.TestCase):
         conn = SolrConnection(base='/solr/mycore')
         conn.flush = MagicMock(name='flush')
         conn.commit()
-        conn.flush.assert_called_once_with(extract_after_commit=True)
+        conn.flush.assert_called_once_with(after_commit=True)
         self.assertEqual(
             conn.update_commands,
             ['"commit": {"softCommit": true, "waitSearcher": true}'])
@@ -93,7 +99,11 @@ class TestConnection(unittest.TestCase):
         self.assertEqual(
             conn.update_commands, ['"optimize": {"waitSearcher": true}'])
 
-    def test_flush_operation_posts_update_commands_and_clears_queue(self):
+    def test_flush_operation_posts_update_commands_and_clears_queue_if_post_commit_hook_disabled(self):
+        registry = queryUtility(IRegistry)
+        settings = registry.forInterface(ISolrSettings)
+        settings.enable_updates_in_post_commit_hook = False
+
         conn = SolrConnection(base='/solr/mycore')
         conn.post = MagicMock(name='post', return_value=SolrResponse(
             body='{"responseHeader":{"status":0}}', status=200))
@@ -103,6 +113,27 @@ class TestConnection(unittest.TestCase):
             '/update', data='{"add": {"doc": {"id": "1"}}}', log_error=False)
         self.assertEqual(conn.update_commands, [])
 
+    def test_flush_operation_adds_updates_to_post_commit_hook_if_enabled(self):
+        hooks = list(transaction.get().getAfterCommitHooks())
+        self.assertEqual(0, len(hooks))
+
+        conn = SolrConnection(base='/solr/mycore')
+        conn.post = MagicMock(name='post', return_value=SolrResponse(
+            body='{"responseHeader":{"status":0}}', status=200))
+        conn.add({'id': '1'})
+        conn.flush()
+        self.assertEqual(conn.update_commands, [])
+        self.assertEqual(0, conn.post.call_count)
+
+        hooks = list(transaction.get().getAfterCommitHooks())
+        self.assertEqual(1, len(hooks))
+        hook = hooks[0]
+        hook[0](True, *hook[1], **hook[2])
+
+        self.assertEqual(1, conn.post.call_count)
+        conn.post.assert_called_once_with(
+            '/update', data='{"add": {"doc": {"id": "1"}}}', log_error=False)
+
     def test_flush_operation_posts_extract_commands_and_clears_queue(self):
         conn = SolrConnection(base='/solr/mycore')
         conn.post = MagicMock(name='post')
@@ -225,7 +256,7 @@ class TestConnection(unittest.TestCase):
         conn.post.return_value.body.get.return_value = 'The searchable text'
         conn.extract(MockBlob(), 'SearchableText', {'id': '1'},
                      'application/octet-stream')
-        conn.flush(extract_after_commit=False)
+        conn.flush(after_commit=False)
 
         args, kwargs = conn.post.call_args_list[0]
         self.assertEqual(
